import logging

"""This module defines NUC44 scoring matrix for RNA sequence alignment.
"""
logger = logging.getLogger(__name__)

NUCLEOTIDE_NUCLEOTIDE_SCORING  = {
    ('A', 'A'): 5, ('A', 'U'): -4, ('A', 'G'): -4, ('A', 'C'): -4,
    ('U', 'U'): 5, ('U', 'A'): -4, ('U', 'G'): -4, ('U', 'C'): -4,
    ('G', 'G'): 5, ('G', 'A'): -4, ('G', 'C'): -4, ('G', 'U'): -4,
    ('C', 'C'): 5, ('C', 'A'): -4, ('C', 'G'): -4, ('C', 'U'): -4,
}


AMBIGUOUS_AMBIGUOUS_SCORING =  {
    ('S', 'S'): -1, ('S', 'W'): -4, ('S', 'R'): -2, ('S', 'Y'): -2,
    ('S', 'K'): -2, ('S', 'M'): -2, ('S', 'B'): -1, ('S', 'V'): -1,
    ('S', 'H'): -3, ('S', 'D'): -3, ('S', 'N'): -1,

    ('W', 'S'): -4, ('W', 'W'): -1, ('W', 'R'): -2, ('W', 'Y'): -2,
    ('W', 'K'): -2, ('W', 'M'): -2, ('W', 'B'): -3, ('W', 'V'): -3,
    ('W', 'H'): -1, ('W', 'D'): -1, ('W', 'N'): -1,

    ('R', 'S'): -2, ('R', 'W'): -2, ('R', 'R'): -1, ('R', 'Y'): -4,
    ('R', 'K'): -2, ('R', 'M'): -2, ('R', 'B'): -3, ('R', 'V'): -1,
    ('R', 'H'): -3, ('R', 'D'): -1, ('R', 'N'): -1,

    ('Y', 'S'): -2, ('Y', 'W'): -2, ('Y', 'R'): -4, ('Y', 'Y'): -1,
    ('Y', 'K'): -2, ('Y', 'M'): -2, ('Y', 'B'): -1, ('Y', 'V'): -3,
    ('Y', 'H'): -1, ('Y', 'D'): -3, ('Y', 'N'): -1,

    ('K', 'S'): -2, ('K', 'W'): -2, ('K', 'R'): -2, ('K', 'Y'): -2,
    ('K', 'K'): -1, ('K', 'M'): -4, ('K', 'B'): -1, ('K', 'V'): -3,
    ('K', 'H'): -3, ('K', 'D'): -1, ('K', 'N'): -1,

    ('M', 'S'): -2, ('M', 'W'): -2, ('M', 'R'): -2, ('M', 'Y'): -2,
    ('M', 'K'): -4, ('M', 'M'): -1, ('M', 'B'): -3, ('M', 'V'): -1,
    ('M', 'H'): -1, ('M', 'D'): -3, ('M', 'N'): -1,

    ('B', 'S'): -1, ('B', 'W'): -3, ('B', 'R'): -3, ('B', 'Y'): -1,
    ('B', 'K'): -1, ('B', 'M'): -3, ('B', 'B'): -1, ('B', 'V'): -2,
    ('B', 'H'): -2, ('B', 'D'): -2, ('B', 'N'): -1,

    ('V', 'S'): -1, ('V', 'W'): -3, ('V', 'R'): -1, ('V', 'Y'): -3,
    ('V', 'K'): -3, ('V', 'M'): -1, ('V', 'B'): -2, ('V', 'V'): -1,
    ('V', 'H'): -2, ('V', 'D'): -2, ('V', 'N'): -1,

    ('H', 'S'): -3, ('H', 'W'): -1, ('H', 'R'): -3, ('H', 'Y'): -1,
    ('H', 'K'): -3, ('H', 'M'): -1, ('H', 'B'): -2, ('H', 'V'): -2,
    ('H', 'H'): -1, ('H', 'D'): -2, ('H', 'N'): -1,

    ('D', 'S'): -3, ('D', 'W'): -1, ('D', 'R'): -1, ('D', 'Y'): -3,
    ('D', 'K'): -1, ('D', 'M'): -3, ('D', 'B'): -2, ('D', 'V'): -2,
    ('D', 'H'): -2, ('D', 'D'): -1, ('D', 'N'): -1,

    ('N', 'S'): -1, ('N', 'W'): -1, ('N', 'R'): -1, ('N', 'Y'): -1,
    ('N', 'K'): -1, ('N', 'M'): -1, ('N', 'B'): -1, ('N', 'V'): -1,
    ('N', 'H'): -1, ('N', 'D'): -1, ('N', 'N'): -1,

}

NUCLEOTIDE_AMBIGUOUS_SCORING = {
    ('A', 'S'): -4, ('A', 'W'): 1, ('A', 'R'): 1, ('A', 'Y'): -4,
    ('A', 'K'): -4, ('A', 'M'): 1, ('A', 'B'): -4, ('A', 'V'): -1,
    ('A', 'H'): -1, ('A', 'D'): -1, ('A', 'N'): -2,

    ('U', 'S'): -4, ('U', 'W'): 1, ('U', 'R'): -4, ('U', 'Y'): 1,
    ('U', 'K'): 1, ('U', 'M'): -4, ('U', 'B'): -1, ('U', 'V'): -4,
    ('U', 'H'): -1, ('U', 'D'): -1, ('U', 'N'): -2,

    ('G', 'S'): 1, ('G', 'W'): -4, ('G', 'R'): 1, ('G', 'Y'): -4,
    ('G', 'K'): 1, ('G', 'M'): -4, ('G', 'B'): -1, ('G', 'V'): -1,
    ('G', 'H'): -4, ('G', 'D'): -1, ('G', 'N'): -2,

    ('C', 'S'): 1, ('C', 'W'): -4, ('C', 'R'): -4, ('C', 'Y'): 1,
    ('C', 'K'): -4, ('C', 'M'): 1, ('C', 'B'): -1, ('C', 'V'): -1,
    ('C', 'H'): -1, ('C', 'D'): -4, ('C', 'N'): -2,

    ('S', 'A'): -4, ('S', 'U'): -4, ('S', 'G'): 1, ('S', 'C'): 1,
    ('W', 'A'): 1, ('W', 'U'): 1, ('W', 'G'): -4, ('W', 'C'): -4,
    ('R', 'A'): 1, ('R', 'U'): -4, ('R', 'G'): 1, ('R', 'C'): -4,
    ('Y', 'A'): -4, ('Y', 'U'): 1, ('Y', 'G'): -4, ('Y', 'C'): 1,
    ('K', 'A'): -4, ('K', 'U'): 1, ('K', 'G'): 1, ('K', 'C'): -4,
    ('M', 'A'): 1, ('M', 'U'): -4, ('M', 'G'): -4, ('M', 'C'): 1,
    ('B', 'A'): -4, ('B', 'U'): -1, ('B', 'G'): -1, ('B', 'C'): -1,
    ('V', 'A'): -1, ('V', 'U'): -4, ('V', 'G'): -1, ('V', 'C'): -1,
    ('H', 'A'): -1, ('H', 'U'): -1, ('H', 'G'): -4, ('H', 'C'): -1,
    ('D', 'A'): -1, ('D', 'U'): -1, ('D', 'G'): -1, ('D', 'C'): -4,
    ('N', 'A'): -2, ('N', 'U'): -2, ('N', 'G'): -2, ('N', 'C'): -2,

}

NUC44 = NUCLEOTIDE_NUCLEOTIDE_SCORING
